@@ -343,7 +343,10 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
             return path_format
 
         def fastapi_after_request(response, request):
-            path_format = get_path_format(request.app.routes, request.url.path)
+            # path_format = get_path_format(request.app.routes, request.url.path)
+            path_format = get_path_format(
+                request.app.routes, request.scope.get("path", request.url.path)
+            )
             if not self.is_exclude(request.method, path_format, response.status_code):
                 request_latency = (
                     time.time() - request._prometheus_metrics_request_start_time
